-- ------------------------------------------------------------------------------ --
--                                TradeSkillMaster                                --
--                http://www.curse.com/addons/wow/tradeskill-master               --
--                                                                                --
--             A TradeSkillMaster Addon (http://tradeskillmaster.com)             --
--    All Rights Reserved* - Detailed license information included with addon.    --
-- ------------------------------------------------------------------------------ --

local _, TSM = ...
local Auctioning = TSM.Operations:NewPackage("Auctioning")
local private = {}
local L = TSM.L
local OPERATION_INFO = {
	-- general
	matchStackSize = { type = "boolean", default = false },
	blacklist = { type = "string", default = "" },
	ignoreLowDuration = { type = "number", default = 0 },
	-- post
	stackSize = { type = "number", default = 1 },
	stackSizeIsCap = { type = "boolean", default = false },
	postCap = { type = "number", default = 5 },
	keepQuantity = { type = "number", default = 0 },
	keepQtySources = { type = "table", default = {} },
	maxExpires = { type = "number", default = 0 },
	duration = { type = "number", default = 24 },
	bidPercent = { type = "number", default = 1 },
	undercut = { type = "string", default = "1c" },
	minPrice = { type = "string", default = "max(0.25*avg(crafting,dbmarket,dbregionmarketavg),1.5*vendorsell)" },
	maxPrice = { type = "string", default = "max(5*avg(crafting,dbmarket,dbregionmarketavg),30*vendorsell)" },
	normalPrice = { type = "string", default = "max(2*avg(crafting,dbmarket,dbregionmarketavg),12*vendorsell)" },
	priceReset = { type = "string", default = "none" },
	aboveMax = { type = "string", default = "normalPrice" },
	-- cancel
	cancelUndercut = { type = "boolean", default = true },
	keepPosted = { type = "number", default = 0 },
	cancelRepost = { type = "boolean", default = true },
	cancelRepostThreshold = { type = "number", default = 10000 },
}



-- ============================================================================
-- Module Functions
-- ============================================================================

function Auctioning.OnInitialize()
	TSM.Operations.Register("Auctioning", OPERATION_INFO, 20, private.GetOperationInfo)
end



-- ============================================================================
-- Private Helper Functions
-- ============================================================================

function private.GetOperationInfo(operationSettings)
	local parts = TSMAPI_FOUR.Util.AcquireTempTable()

	-- get the post string
	if operationSettings.postCap == 0 then
		tinsert(parts, L["No posting."])
	else
		tinsert(parts, format(L["Posting %d stack(s) of %d for %d hours."], operationSettings.postCap, operationSettings.stackSize, operationSettings.duration))
	end

	-- get the cancel string
	if operationSettings.cancelUndercut and operationSettings.cancelRepost then
		tinsert(parts, format(L["Canceling undercut auctions and to repost higher."]))
	elseif operationSettings.cancelUndercut then
		tinsert(parts, format(L["Canceling undercut auctions."]))
	elseif operationSettings.cancelRepost then
		tinsert(parts, format(L["Canceling to repost higher."]))
	else
		tinsert(parts, L["Not canceling."])
	end

	local result = table.concat(parts, " ")
	TSMAPI_FOUR.Util.ReleaseTempTable(parts)
	return result
end
